@@ -1,4 +1,4 @@
-#$Id: Node.pm 285 2013-11-16 17:41:28Z maj $
+#$Id: Node.pm 315 2013-12-27 01:52:16Z maj $
 package REST::Neo4p::Node;
 use base 'REST::Neo4p::Entity';
 use REST::Neo4p::Relationship;
@@ -8,7 +8,7 @@ use Carp qw(croak carp);
 use strict;
 use warnings;
 BEGIN {
-  $REST::Neo4p::Node::VERSION = '0.2200';
+  $REST::Neo4p::Node::VERSION = '0.2230';
 }
 
 # creation, deletion and property manipulation are delegated
@@ -276,11 +276,18 @@ Sets values of properties on nodes and relationships.
 
 =item get_properties()
 
- $props = $relationship->get_properties;
+ $props = $node->get_properties;
  print "'Sup, Al." if ($props->{name} eq 'Al');
 
 Get all the properties of a node or relationship as a hashref.
 
+=item remove_property()
+
+ $node->remove_property('name');
+ $node->remove_property(@property_names);
+
+Remove properties from node.
+
 =item relate_to()
 
  $relationship = $node1->relate_to($node2, 'manager', { matrixed => 'yes' });
